@@ -131,15 +131,14 @@ def ArgumentParser(profile, profile_arg=True):
                                  help='This is a slightly more compact and succint'
                                       ' output layout.')
 
-    if sys.platform != "win32":
-        argument_parser.add_argument('-n', '--no-progress',
-                                     action='store_true',
-                                     help='In a tty as stdout, don\'t'
-                                          ' render the progress indicators.')
+    argument_parser.add_argument('-n', '--no-progress',
+                                 default=False, action='store_true',
+                                 help='In a tty as stdout, don\'t'
+                                      ' render the progress indicators.')
 
-        argument_parser.add_argument('-C', '--no-colors',
-                                     action='store_true',
-                                     help='No colors for tty output.')
+    argument_parser.add_argument('-C', '--no-colors',
+                                 default=False, action='store_true',
+                                 help='No colors for tty output.')
 
     argument_parser.add_argument('-S', '--show-sections', default=False, action='store_true',
                                  help='Show section summaries.')
@@ -271,12 +270,6 @@ def main(profile=None, values=None):
         argument_parser.print_usage()
         sys.exit(1)
 
-    # The default Windows Terminal just displays the escape codes. The argument
-    # parser above therefore has these options disabled.
-    if sys.platform == "win32":
-        args.no_progress = True
-        args.no_colors = True
-
     theme = get_theme(args)
     # the most verbose loglevel wins
     loglevel = min(args.loglevels) if args.loglevels else DEFAULT_LOG_LEVEL
@@ -300,11 +293,23 @@ def main(profile=None, values=None):
     else:
         configuration = Configuration()
 
+    # Since version 0.8.10, we established a convention of never using a dash/hyphen
+    # on check IDs. The existing ones were replaced by underscores.
+    # All new checks will use underscores when needed.
+    # Here we accept dashes to ensure backwards compatibility with the older
+    # check IDs that may still be referenced on scripts of our users.
+    explicit_checks = None
+    exclude_checks = None
+    if args.checkid:
+        explicit_checks = [c.replace('-', '_') for c in list(args.checkid)]
+    if args.exclude_checkid:
+        exclude_checks = [x.replace('-', '_') for x in list(args.exclude_checkid)]
+
     # Command line args overrides config, but only if given
     configuration.maybe_override(Configuration(
         custom_order=args.order,
-        explicit_checks=args.checkid,
-        exclude_checks=args.exclude_checkid,
+        explicit_checks=explicit_checks,
+        exclude_checks=exclude_checks,
         full_lists=args.full_lists
     ))
     runner_kwds = dict(values=values_, config=configuration)
