@@ -58,7 +58,7 @@ def _style_tokens(string):
 def _parse_name(wght, ital):
     if wght == "Regular" and ital == "Italic":
         wght = ""
-    result = "{} {}".format(wght, ital).lstrip().rstrip()
+    result = f"{wght} {ital}".lstrip().rstrip()
     # replace multiple whitespace characters with a single space"
     return re.sub(r"\W+", " ", result)
 
@@ -139,10 +139,13 @@ def style_parse(ttFont):
     import os
     filename = os.path.basename(ttFont.reader.file.name)
     if len(filename.split("-")) != 2:
-        style = "Regular"
+        # Google Fonts policy on font file naming scheme
+        # requires that only a single dash is used
+        # to separate family name from style.
+        return None
     else:
         style = filename.split("-")[1].split(".")[0]
-    return _style_parse(style)
+        return _style_parse(style)
 
 
 def instance_parse(string):
