@@ -9,7 +9,7 @@ from fontbakery.fonts_profile import profile_factory # NOQA pylint: disable=unus
 @condition
 def has_kerning_info(ttFont):
     """A font has kerning info if it has a GPOS table containing at least one
-    Pair Adjustment lookup (eigther directly or through an extension
+    Pair Adjustment lookup (either directly or through an extension
     subtable)."""
     if "GPOS" not in ttFont:
         return False
@@ -27,7 +27,8 @@ def has_kerning_info(ttFont):
 
 
 @check(
-    id = 'com.google.fonts/check/gpos_kerning_info'
+    id = 'com.google.fonts/check/gpos_kerning_info',
+    proposal = 'legacy:check/063'
 )
 def com_google_fonts_check_gpos_kerning_info(ttFont):
     """Does GPOS table have kerning information?
