@@ -18,7 +18,7 @@ import uharfbuzz as hb
 profile = profile_factory(default_section=Section("Suitability for In-Car Display"))
 
 DISCLAIMER = """
-        (Note that PASSing this check does not guarantee compliance with ISO 15008.)
+        (Note that passing this check does not guarantee compliance with ISO-15008.)
 """
 
 CHECKS = [
@@ -87,9 +87,13 @@ def pair_kerning(font, left, right):
 @check(
     id = 'com.google.fonts/check/iso15008_proportions',
     rationale = """
-        According to ISO 15008, fonts used for in-car displays should not be too narrow or too wide.
-        To ensure legibility of this font on in-car information systems, it is recommended that the ratio of H width to H height is between 0.65 and 0.80."""
-    + DISCLAIMER,
+        According to ISO 15008, fonts used for in-car displays should not be
+        too narrow or too wide.
+        
+        To ensure legibility of this font on in-car information systems,
+        it is recommended that the ratio of H width to H height
+        is between 0.65 and 0.80.
+    """ + DISCLAIMER,
     proposal = ['https://github.com/googlefonts/fontbakery/issues/1832',
                 'https://github.com/googlefonts/fontbakery/issues/3250']
 )
@@ -119,9 +123,13 @@ def com_google_fonts_check_iso15008_proportions(ttFont):
 @check(
     id = 'com.google.fonts/check/iso15008_stem_width',
     rationale = """
-        According to ISO 15008, fonts used for in-car displays should not be too light or too bold.
-        To ensure legibility of this font on in-car information systems, it is recommended that the ratio of stem width to ascender height is between 0.10 and 0.20."""
-    + DISCLAIMER,
+        According to ISO 15008, fonts used for in-car displays should
+        not be too light or too bold.
+        
+        To ensure legibility of this font on in-car information systems,
+        it is recommended that the ratio of stem width to ascender height
+        is between 0.10 and 0.20.
+    """ + DISCLAIMER,
     proposal = ['https://github.com/googlefonts/fontbakery/issues/1832',
                 'https://github.com/googlefonts/fontbakery/issues/3251']
 )
@@ -147,12 +155,20 @@ def com_google_fonts_check_iso15008_stem_width(ttFont):
 @check(
     id = 'com.google.fonts/check/iso15008_intercharacter_spacing',
     rationale = """
-        According to ISO 15008, fonts used for in-car displays should not be too narrow or too wide.
-        To ensure legibility of this font on in-car information systems it is recommended that the spacing falls within the following values:
-        * space between vertical strokes (e.g. "ll") should be 150%-240% of the stem width.
-        * space between diagonals and verticals (e.g. "vl") should be at least 85% of the stem width.
-        * diagonal characters should not touch (e.g. "vv")."""
-    + DISCLAIMER,
+        According to ISO 15008, fonts used for in-car displays should not
+        be too narrow or too wide.
+        
+        To ensure legibility of this font on in-car information systems,
+        it is recommended that the spacing falls within the following values:
+        
+        * space between vertical strokes (e.g. "ll") should be 150%-240%
+          of the stem width.
+        
+        * space between diagonals and verticals (e.g. "vl") should be
+          at least 85% of the stem width.
+        
+        * diagonal characters should not touch (e.g. "vv").
+    """ + DISCLAIMER,
     proposal = ['https://github.com/googlefonts/fontbakery/issues/1832',
                 'https://github.com/googlefonts/fontbakery/issues/3252']
 )
@@ -228,9 +244,13 @@ def com_google_fonts_check_iso15008_intercharacter_spacing(font, ttFont):
 @check(
     id = 'com.google.fonts/check/iso15008_interword_spacing',
     rationale = """
-        According to ISO 15008, fonts used for in-car displays should not be too narrow or too wide.
-        To ensure legibility of this font on in-car information systems it is recommended that the space character should have advance width between 250% and 300% of the space between the letters l and m."""
-    + DISCLAIMER,
+        According to ISO 15008, fonts used for in-car displays
+        should not be too narrow or too wide.
+        
+        To ensure legibility of this font on in-car information systems,
+        it is recommended that the space character should have advance width
+        between 250% and 300% of the space between the letters l and m.
+    """ + DISCLAIMER,
     proposal = ['https://github.com/googlefonts/fontbakery/issues/1832',
                 'https://github.com/googlefonts/fontbakery/issues/3253']
 )
@@ -275,9 +295,14 @@ def com_google_fonts_check_iso15008_interword_spacing(font, ttFont):
 @check(
     id = 'com.google.fonts/check/iso15008_interline_spacing',
     rationale = """
-        According to ISO 15008, fonts used for in-car displays should not be too narrow or too wide.
-        To ensure legibility of this font on in-car information systems it is recommended that  the vertical metrics be set to a minimum at least one stem width between the bottom of the descender and the top of the ascender."""
-    + DISCLAIMER,
+        According to ISO 15008, fonts used for in-car displays
+        should not be too narrow or too wide.
+        
+        To ensure legibility of this font on in-car information systems,
+        it is recommended that the vertical metrics be set to a minimum
+        at least one stem width between the bottom of the descender
+        and the top of the ascender.
+    """ + DISCLAIMER,
     proposal = ['https://github.com/googlefonts/fontbakery/issues/1832',
                 'https://github.com/googlefonts/fontbakery/issues/3254']
 )
