@@ -16,8 +16,8 @@ class GHMarkdownReporter(SerializeReporter):
               f' for posting issues on a GitHub issue tracker has been\n'
               f' saved to "{self.output_file}"')
 
-
-    def emoticon(self, name):
+    @staticmethod
+    def emoticon(name):
         return {
             'ERROR': "\U0001F494", # 💔  :broken_heart:
             'FAIL':  "\U0001F525", # 🔥  :fire:
@@ -42,8 +42,8 @@ class GHMarkdownReporter(SerializeReporter):
         if self.succinct or not "rationale" in check:
             return ""
 
-        from fontbakery.utils import unindent_rationale
-        content = unindent_rationale(check['rationale'], checkid)
+        from fontbakery.utils import unindent_and_unwrap_rationale
+        content = unindent_and_unwrap_rationale(check['rationale'], checkid)
         return "\n".join([ ">" + line for line in content.split("\n")])
 
     def check_md(self, check):
@@ -52,7 +52,7 @@ class GHMarkdownReporter(SerializeReporter):
 
         check["logs"].sort(key=lambda c: c["status"])
         logs = "".join(map(self.log_md, check["logs"]))
-        github_search_url = ( "<a href=\"https://font-bakery.readthedocs.io/en/latest"
+        github_search_url = ( "<a href=\"https://font-bakery.readthedocs.io/en/stable"
                              f"/fontbakery/profiles/{profile}.html#{checkid}\">"
                              f"{checkid}</a>" )
 
@@ -64,19 +64,21 @@ class GHMarkdownReporter(SerializeReporter):
                                                                 github_search_url),
                                       f"\n\n{rationale}\n{logs}")
 
-    def deduce_profile_from_section_name(self, section):
+    @staticmethod
+    def deduce_profile_from_section_name(section):
         # This is very hacky!
         # We should have a much better way of doing it...
         if 'Google Fonts' in section: return 'googlefonts'
         if 'Adobe' in section: return 'adobefonts'
-        if 'Type Network' in section: return 'typenetwork'
+        if 'Font Bureau' in section: return 'fontbureau'
         if 'Universal' in section: return 'universal'
         if 'Basic UFO checks' in section: return 'ufo_sources'
         if 'Checks inherited from Microsoft Font Validator' in section: return 'fontval'
         if 'fontbakery.profiles.' in section: return section.split('fontbakery.profiles.')[1].split('>')[0]
         return section
 
-    def result_is_all_same(self, cluster):
+    @staticmethod
+    def result_is_all_same(cluster):
         first_check = cluster[0]
         return all(check["logs"] == first_check["logs"] for check in cluster[1:])
 
