@@ -242,7 +242,8 @@ class TerminalProgress(FontbakeryReporter):
             self._progressbar.append('.')
         return index
 
-    def _reset_progress(self, num_linebeaks):
+    @staticmethod
+    def _reset_progress(num_linebeaks):
         # BACKSPACE = u'\b'
         TOLEFT = '\u001b[1000D' # Move all the way left (max 1000 steps
         CLEARLINE = '\u001b[2K'    # Clear the line
@@ -250,35 +251,40 @@ class TerminalProgress(FontbakeryReporter):
         reset = (CLEARLINE + UP) * num_linebeaks + TOLEFT
         return reset
 
+    @staticmethod
+    def _needs_break(count, columns, right_margin):
+        return (
+            columns and count > columns and (count % (columns - right_margin))
+        )
+
     def _draw_progressbar(self, columns=None, len_prefix=0, right_margin=0):
         """
         if columns is None, don't insert any extra line breaks
         """
-        if self._order == None:
+        if self._order is None:
             total = len(self._results)
         else:
             total = max(len(self._order), len(self._results))
 
-        percent = int(round(len(self._results)/total*100)) if total else 0
-
-        needs_break = lambda count: columns and count > columns \
-                                    and (count % (columns - right_margin))
+        percent = int(round(len(self._results) / total * 100)) if total else 0
 
         # together with unicode_literals `str('status')` seems the best
         # py2 and py3 compatible solution
-        status = type(str('status'), (object,), dict(count=0,progressbar=[]))
+        status = type(str('status'), (object,), dict(count=0, progressbar=[]))
+
         def _append(status, item, length=1, separator=''):
             # * assuming a standard item will take one column in the tty
             # * length must not be bigger than columns (=very narrow columns)
             progressbar = status.progressbar
-            if needs_break(status.count + length + len(separator)):
+            if self._needs_break(status.count + length + len(separator),
+                                 columns, right_margin):
                 progressbar.append('\n')
                 status.count = 0
             else:
                 progressbar.append(separator)
             status.count += length + len(separator)
             progressbar.append(item)
-        append=partial(_append, status)
+        append = partial(_append, status)
         progressbar = status.progressbar
 
         append('', len_prefix)
@@ -290,7 +296,6 @@ class TerminalProgress(FontbakeryReporter):
         append(percentstring, len(percentstring), ' ')
         return ''.join(progressbar)
 
-
     def draw_progressbar(self):
         # tty size
         if sys.platform == "win32":
@@ -428,13 +433,14 @@ class TerminalReporter(TerminalProgress):
                     with_string))
 
                 if check.rationale:
-                    from fontbakery.utils import text_flow, unindent_rationale
-                    content = unindent_rationale(check.rationale).strip()
+                    from fontbakery.utils import text_flow, unindent_and_unwrap_rationale
+                    content = unindent_and_unwrap_rationale(check.rationale)
                     print('    ' + self.theme["rationale-title"]("  Rationale:" + " " * 64) + '\n'
                           + text_flow(content,
                                       width=76,
                                       indent=4,
                                       left_margin=2,
+                                      right_margin=1,
                                       space_padding=True,
                                       text_color=self.theme["rationale-text"]))
 
@@ -594,7 +600,7 @@ def parse_md(md):
         console.print(Markdown(md))
     formated_text = capture.get()
     for i in range(len(tables)):
-        formated_text = re.sub('<#MD-TABLE-'+str(i)+'#>', tables[i], formated_text)
+        formated_text = formated_text.replace(f'<#MD-TABLE-{i}#>', tables[i], 1)
     return re.sub(r'<br/?>', r'\n', formated_text).strip()
 
 def parse_md_table(match, tables_memo):
