@@ -1,7 +1,5 @@
 import os
-from types import SimpleNamespace
 
-import fontTools.ttLib
 from fontTools.ttLib import TTFont
 
 from fontbakery.constants import (NameID,
@@ -10,7 +8,7 @@ from fontbakery.constants import (NameID,
                                   WindowsLanguageID,
                                   MacintoshEncodingID,
                                   MacintoshLanguageID)
-from fontbakery.checkrunner import (INFO, WARN, PASS, FAIL)
+from fontbakery.checkrunner import INFO, WARN, PASS, FAIL, SKIP
 from fontbakery.codetesting import (assert_PASS,
                                     assert_results_contain,
                                     CheckTester,
@@ -181,44 +179,111 @@ def test_check_monospace():
     assert (status == WARN and message.code == "mono-outliers") or \
            (status == PASS and message.code == "mono-good")
 
+    # Confirm the check yields FAIL if the font doesn't have a required table
+    del ttFont["OS/2"]
+    assert_results_contain(check(ttFont), FAIL, "lacks-table")
+
 
 def test_check_name_match_familyname_fullfont():
     """ Does full font name begin with the font family name? """
     check = CheckTester(opentype_profile,
                         "com.google.fonts/check/name/match_familyname_fullfont")
+
     # Our reference Mada Regular is known to be good
     ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
 
     # So it must PASS the check:
-    assert_PASS(check(ttFont),
-                'with a good font...')
+    msg = assert_PASS(check(ttFont))
+    assert msg == "Full font name begins with the font family name."
 
-    # alter the full-font-name prepending a bad prefix:
-    for i, name in enumerate(ttFont["name"].names):
-        if name.nameID == NameID.FULL_FONT_NAME:
-            ttFont["name"].names[i].string = "bad-prefix".encode(name.getEncoding())
+    EXPECTED_NAME_STRING = "Mada"
+    BAD_PREFIX = "bad-prefix"
+    name_table = ttFont["name"]
+    platform_id = 3
+    encoding_id = 1
+    language_id = 0x0409
+    family_name_id = NameID.FONT_FAMILY_NAME
+    full_name_id = NameID.FULL_FONT_NAME
 
-    # and make sure the check FAILs:
-    assert_results_contain(check(ttFont),
-                           FAIL, 'does-not',
-                           'with a font in which the family name'
-                           ' begins with a digit...')
+    # Alter the font's full_name string and re-run the check.
+    # 1. Retrieve the existing name strings and assert that they're the expected ones.
+    family_name = name_table.getName(
+        family_name_id, platform_id, encoding_id, language_id).toUnicode()
+    assert family_name == EXPECTED_NAME_STRING
 
-    ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-    for i, name in enumerate(ttFont["name"].names):
-        if name.nameID == NameID.FULL_FONT_NAME:
-            del ttFont["name"].names[i]
-    assert_results_contain(check(ttFont),
-                           FAIL, 'no-full-font-name',
-                           'with no FULL_FONT_NAME entries...')
+    full_name_before = name_table.getName(
+        full_name_id, platform_id, encoding_id, language_id).toUnicode()
+    assert full_name_before == EXPECTED_NAME_STRING
 
-    ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-    for i, name in enumerate(ttFont["name"].names):
-        if name.nameID == NameID.FONT_FAMILY_NAME:
-            del ttFont["name"].names[i]
-    assert_results_contain(check(ttFont),
-                           FAIL, 'no-font-family-name',
-                           'with no FONT_FAMILY_NAME entries...')
+    # 2. Prefix the full_name string, and update the font's name record.
+    name_table.setName(f"{BAD_PREFIX}{full_name_before}", full_name_id,
+                       platform_id, encoding_id, language_id)
+
+    # 3. Retrieve the updated name string, and assert that it's the expected one.
+    full_name_after = name_table.getName(
+        full_name_id, platform_id, encoding_id, language_id).toUnicode()
+    assert full_name_after != family_name
+    assert full_name_after == f"{BAD_PREFIX}{EXPECTED_NAME_STRING}"
+    assert full_name_after.startswith(BAD_PREFIX)
+
+    # 4. Now re-run the check. It should yield FAIL because the full_name string
+    # no longer starts with the family_name string.
+    msg = assert_results_contain(check(ttFont), FAIL, "mismatch-font-names")
+    assert msg == (f"On the 'name' table, the full font name {full_name_after!r}"
+                   f" does not begin with the font family name {family_name!r}"
+                   f" in platformID {platform_id},"
+                   f" encodingID {encoding_id},"
+                   f" languageID {language_id}({language_id:04X}),"
+                   f" and nameID {family_name_id}.")
+
+    # Remove the modified full name record and re-run the check.
+    # It should yield FAIL because the name table won't contain a full name string
+    # to compare with the family name string.
+    name_table.removeNames(full_name_id, platform_id, encoding_id, language_id)
+    msg = assert_results_contain(check(ttFont), FAIL, "missing-font-names")
+    assert msg == (
+        f"The font's 'name' table lacks a pair of records with"
+        f" nameID {NameID.FULL_FONT_NAME} (Full name),"
+        f" and at least one of"
+        f" nameID {NameID.FONT_FAMILY_NAME} (Font Family name),"
+        f" {NameID.TYPOGRAPHIC_FAMILY_NAME} (Typographic Family name),"
+        f" or {NameID.WWS_FAMILY_NAME} (WWS Family name)."
+    )
+
+    # Run the check on a CJK font. The font's 'name' table contains
+    # English-US (1033/0x0409) and Japanese (1041/0x0411) records. It should PASS.
+    ttFont = TTFont(TEST_FILE("cjk/SourceHanSans-Regular.otf"))
+    msg = assert_PASS(check(ttFont))
+    assert msg == "Full font name begins with the font family name."
+
+    name_table = ttFont["name"]
+    decode_error_msg_prefix = (
+        f"On the 'name' table, the name record"
+        f" for platformID {platform_id},"
+        f" encodingID {encoding_id},"
+        f" languageID {language_id}({language_id:04X}),"
+    )
+
+    # Replace the English full name string with data that can't be 'utf_16_be'-decoded.
+    # This will cause a UnicodeDecodeError which will yield a FAIL.
+    name_table.setName("\xff".encode("utf_7"),
+                       full_name_id, platform_id, encoding_id, language_id)
+    msg = assert_results_contain(
+        check(ttFont), FAIL, f"cannot-decode-nameid-{full_name_id}")
+    assert msg == (
+        f"{decode_error_msg_prefix} and nameID {full_name_id} failed to be decoded."
+    )
+
+    # This time replace the family name string instead.
+    # This should still trigger a UnicodeDecodeError.
+    name_table = ttFont["name"]
+    name_table.setName("\xff".encode("utf_7"),
+                       family_name_id, platform_id, encoding_id, language_id)
+    msg = assert_results_contain(
+        check(ttFont), FAIL, f"cannot-decode-nameid-{family_name_id}")
+    assert msg == (
+        f"{decode_error_msg_prefix} and nameID {family_name_id} failed to be decoded."
+    )
 
 
 def assert_name_table_check_result(ttFont, index, name, check, value, expected_result, expected_keyword=None):
@@ -322,31 +387,41 @@ def test_check_family_naming_recommendations():
 def test_check_name_postscript_vs_cff():
     check = CheckTester(opentype_profile,
                         "com.adobe.fonts/check/name/postscript_vs_cff")
-    test_font = TTFont()
-    test_font['CFF '] = fontTools.ttLib.newTable('CFF ')
-    test_font['CFF '].cff.fontNames = ['SomeFontName']
-    test_font['name'] = fontTools.ttLib.newTable('name')
 
-    test_font['name'].setName(
-        'SomeOtherFontName',
+    # Test a font that has matching names. Check should PASS.
+    ttFont = TTFont(TEST_FILE("source-sans-pro/OTF/SourceSansPro-Bold.otf"))
+    msg = assert_PASS(check(ttFont))
+    assert msg == "Name table PostScript name matches CFF table FontName."
+
+    # Change the name-table string. Check should FAIL.
+    other_name = 'SomeOtherFontName'
+    ttFont['name'].setName(
+        other_name,
         NameID.POSTSCRIPT_NAME,
         PlatformID.WINDOWS,
         WindowsEncodingID.UNICODE_BMP,
         WindowsLanguageID.ENGLISH_USA
     )
+    msg = assert_results_contain(check(ttFont), FAIL, "ps-cff-name-mismatch")
+    assert msg == (f"Name table PostScript name '{other_name}' does not match"
+                   " CFF table FontName 'SourceSansPro-Bold'.")
 
-    test_font.reader = SimpleNamespace(file=SimpleNamespace(name="whatever"))
-    assert_results_contain(check(test_font),
-                           FAIL, 'mismatch')
+    # Change the CFF-table name. Check should FAIL.
+    ttFont['CFF '].cff.fontNames = ["name1", "name2"]
+    msg = assert_results_contain(check(ttFont), FAIL, "cff-name-error")
+    assert msg == "Unexpected number of font names in CFF table."
 
-    test_font['name'].setName(
-        'SomeFontName',
-        NameID.POSTSCRIPT_NAME,
-        PlatformID.WINDOWS,
-        WindowsEncodingID.UNICODE_BMP,
-        WindowsLanguageID.ENGLISH_USA
-    )
-    assert_PASS(check(test_font))
+    # Now test with a TrueType font.
+    # The test should be skipped due to an unfulfilled condition.
+    ttFont = TTFont(TEST_FILE("source-sans-pro/TTF/SourceSansPro-Bold.ttf"))
+    msg = assert_results_contain(check(ttFont), SKIP, "unfulfilled-conditions")
+    assert msg == "Unfulfilled Conditions: is_cff"
+
+    # Now test with a CFF2 font.
+    # The test should be skipped due to an unfulfilled condition.
+    ttFont = TTFont(TEST_FILE("source-sans-pro/VAR/SourceSansVariable-Italic.otf"))
+    msg = assert_results_contain(check(ttFont), SKIP, "unfulfilled-conditions")
+    assert msg == "Unfulfilled Conditions: is_cff"
 
 
 def test_check_name_postscript_name_consistency():
