@@ -1,16 +1,18 @@
-import pytest
 import io
-import os
-from fontTools.ttLib import TTFont
+from unittest.mock import patch, MagicMock
 
-from fontbakery.checkrunner import (INFO, WARN, FAIL)
+from fontTools.ttLib import TTFont
+import pytest
+from requests.exceptions import ConnectionError
+
+from fontbakery.checkrunner import INFO, WARN, FAIL, PASS, SKIP
 from fontbakery.codetesting import (assert_PASS,
                                     assert_SKIP,
                                     assert_results_contain,
                                     CheckTester,
                                     TEST_FILE)
-from fontbakery.constants import NameID
 from fontbakery.profiles import universal as universal_profile
+from fontbakery.profiles.universal import is_up_to_date
 
 
 @pytest.fixture
@@ -88,17 +90,21 @@ def test_check_valid_glyphnames():
 
     # Nowadays, it seems most implementations can deal with
     # up to 63 char glyph names:
-    good_name = "b" * 63
+    good_name1 = "b" * 63
+    # colr font may have a color layer in .notdef so allow these layers
+    good_name2 = ".notdef.color0"
     bad_name1 = "a" * 64
     bad_name2 = "3cents"
     bad_name3 = ".threecents"
     ttFont.glyphOrder[2] = bad_name1
     ttFont.glyphOrder[3] = bad_name2
     ttFont.glyphOrder[4] = bad_name3
-    ttFont.glyphOrder[5] = good_name
+    ttFont.glyphOrder[5] = good_name1
+    ttFont.glyphOrder[6] = good_name2
     message = assert_results_contain(check(ttFont),
                                      FAIL, 'found-invalid-names')
-    assert good_name not in message
+    assert good_name1 not in message
+    assert good_name2 not in message
     assert bad_name1 in message
     assert bad_name2 in message
     assert bad_name3 in message
@@ -207,7 +213,7 @@ def DISABLED_test_check_glyphnames_max_length():
 def test_check_ttx_roundtrip():
     """ Checking with fontTools.ttx """
     check = CheckTester(universal_profile,
-                        "com.google.fonts/check/ttx-roundtrip")
+                        "com.google.fonts/check/ttx_roundtrip")
 
     font = TEST_FILE("mada/Mada-Regular.ttf")
     assert_PASS(check(font))
@@ -219,29 +225,6 @@ def test_check_ttx_roundtrip():
     #                        FAIL, None) # FIXME: This needs a message keyword
 
 
-def test_is_up_to_date():
-    from fontbakery.profiles.universal import is_up_to_date
-    # is_up_to_date(installed, latest)
-    assert(is_up_to_date(installed="0.5.0",
-                            latest="0.5.0") == True)
-    assert(is_up_to_date(installed="0.5.1",
-                            latest="0.5.0") == True)
-    assert(is_up_to_date(installed="0.4.1",
-                            latest="0.5.0") == False)
-    assert(is_up_to_date(installed="0.3.4",
-                            latest="0.3.5") == False)
-    assert(is_up_to_date(installed="1.0.0",
-                            latest="1.0.1") == False)
-    assert(is_up_to_date(installed="2.0.0",
-                            latest="1.5.3") == True)
-    assert(is_up_to_date(installed="0.5.2.dev73+g8c9ebc0.d20181023",
-                            latest="0.5.1") == True)
-    assert(is_up_to_date(installed="0.5.2.dev73+g8c9ebc0.d20181023",
-                            latest="0.5.2") == False)
-    assert(is_up_to_date(installed="0.5.2.dev73+g8c9ebc0.d20181023",
-                            latest="0.5.3") == False)
-
-
 def test_check_name_trailing_spaces():
     """ Name table entries must not have trailing spaces. """
     check = CheckTester(universal_profile,
@@ -300,6 +283,113 @@ def test_check_ots():
     assert "Failed to sanitize file!" in message
 
 
+@pytest.mark.parametrize('installed, latest, result', [
+    # True when installed >= latest
+    ("0.5.0", "0.5.0", True),
+    ("0.5.1", "0.5.0", True),
+    ("0.5.1", "0.5.0.post2", True),
+    ("2.0.0", "1.5.1", True),
+    ("0.8.10", "0.8.9", True),
+    ("0.5.2.dev73+g8c9ebc0.d20181023", "0.5.1", True),
+    ("0.8.10.dev1+g666b3425", "0.8.9", True),
+    ("0.8.10.dev2+gfa9260bf", "0.8.9.post2", True),
+    ("0.8.10a9", "0.8.9", True),
+    ("0.8.10rc1.dev3+g494879af.d20220825", "0.8.9", True),
+
+    # False when installed < latest
+    ("0.4.1", "0.5.0", False),
+    ("0.3.4", "0.3.5", False),
+    ("1.0.0", "1.0.1", False),
+    ("0.8.9", "0.8.10", False),
+    ("0.5.0", "0.5.0.post2", False),
+    ("0.8.9.dev1+g666b3425", "0.8.9.post2", False),
+    ("0.5.2.dev73+g8c9ebc0.d20181023", "0.5.2", False),
+    ("0.5.2.dev73+g8c9ebc0.d20181023", "0.5.3", False),
+    ("0.8.10rc0", "0.8.10", False),
+    ("0.8.10rc0", "0.8.10.post", False),
+    ("0.8.10rc1.dev3+g494879af.d20220825", "0.8.10", False),
+    ("0.8.10rc1.dev3+g494879af.d20220825", "0.8.10.post", False),
+])
+def test_is_up_to_date(installed, latest, result):
+    assert is_up_to_date(installed, latest) is result
+
+
+class MockDistribution:
+    """Helper class to mock pip-api's Distribution class."""
+
+    def __init__(self, version: str):
+        self.name = "fontbakery"
+        self.version = version
+
+    def __repr__(self):
+        return f"<Distribution(name='{self.name}', version='{self.version}')>"
+
+
+# We don't want to make an actual GET request to PyPI.org, so we'll mock it.
+# We'll also mock pip-api's 'installed_distributions' method.
+@patch("pip_api.installed_distributions")
+@patch("requests.get")
+def test_check_fontbakery_version(mock_get, mock_installed):
+    """Check if Font Bakery is up-to-date"""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/fontbakery_version")
+
+    # Any of the test fonts can be used here.
+    # The check requires a 'font' argument but it doesn't do anything with it.
+    font = TEST_FILE("nunito/Nunito-Regular.ttf")
+
+    mock_response = MagicMock()
+    mock_response.status_code = 200
+
+    # Test the case of installed version being the same as PyPI's version.
+    latest_ver = installed_ver = "0.1.0"
+    mock_response.json.return_value = {"info": {"version": latest_ver}}
+    mock_get.return_value = mock_response
+    mock_installed.return_value = {"fontbakery": MockDistribution(installed_ver)}
+    msg = assert_PASS(check(font), PASS)
+    assert msg == "Font Bakery is up-to-date."
+
+    # Test the case of installed version being newer than PyPI's version.
+    installed_ver = "0.1.1"
+    mock_installed.return_value = {"fontbakery": MockDistribution(installed_ver)}
+    msg = assert_PASS(check(font), PASS)
+    assert msg == "Font Bakery is up-to-date."
+
+    # Test the case of installed version being older than PyPI's version.
+    installed_ver = "0.0.1"
+    mock_installed.return_value = {"fontbakery": MockDistribution(installed_ver)}
+    msg = assert_results_contain(check(font), FAIL, "outdated-fontbakery")
+    assert (f"Current Font Bakery version is {installed_ver},"
+            f" while a newer {latest_ver} is already available.") in msg
+
+    # Test the case of an unsuccessful response to the GET request.
+    mock_response.status_code = 500
+    mock_response.content = "500 Internal Server Error"
+    msg = assert_results_contain(check(font), FAIL, "unsuccessful-request-500")
+    assert "Request to PyPI.org was not successful" in msg
+
+    # Test the case of the GET request failing due to a connection error.
+    mock_get.side_effect = ConnectionError
+    msg = assert_results_contain(check(font), FAIL, "connection-error")
+    assert "Request to PyPI.org failed with this message" in msg
+
+
+def test_check_fontbakery_version_live_apis():
+    """Check if Font Bakery is up-to-date. (No API-mocking edition)"""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/fontbakery_version")
+
+    # Any of the test fonts can be used here.
+    # The check requires a 'font' argument but it doesn't do anything with it.
+    font = TEST_FILE("nunito/Nunito-Regular.ttf")
+
+    # The check will make an actual request to PyPI.org,
+    # and will query 'pip' to determine which version of 'fontbakery' is installed.
+    # The check should PASS.
+    msg = assert_PASS(check(font), PASS)
+    assert msg == "Font Bakery is up-to-date."
+
+
 def test_check_mandatory_glyphs():
     """ Font contains the first few mandatory glyphs (.null or NULL, CR and space)? """
     check = CheckTester(universal_profile,
@@ -326,6 +416,12 @@ def test_check_mandatory_glyphs():
     #                              WARN, 'first-glyph')
 
 
+def _remove_cmap_entry(font, cp):
+    """Helper method that removes a codepoint entry from all the tables in cmap."""
+    for subtable in font['cmap'].tables:
+        subtable.cmap.pop(cp, None)
+
+
 def test_check_whitespace_glyphs():
     """ Font contains glyphs for whitespace characters? """
     check = CheckTester(universal_profile,
@@ -337,9 +433,7 @@ def test_check_whitespace_glyphs():
                 'with a good font...')
 
     # We remove the nbsp char (0x00A0)
-    for table in ttFont['cmap'].tables:
-        if 0x00A0 in table.cmap:
-            del table.cmap[0x00A0]
+    _remove_cmap_entry(ttFont, 0x00A0)
 
     # And make sure the problem is detected:
     assert_results_contain(check(ttFont),
@@ -350,9 +444,7 @@ def test_check_whitespace_glyphs():
     ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
 
     # And finally do the same with the space character (0x0020):
-    for table in ttFont['cmap'].tables:
-        if 0x0020 in table.cmap:
-            del table.cmap[0x0020]
+    _remove_cmap_entry(ttFont, 0x0020)
     assert_results_contain(check(ttFont),
                            FAIL, 'missing-whitespace-glyph-0x0020',
                            'with a font lacking a space (0x0020)...')
@@ -363,18 +455,6 @@ def test_check_whitespace_glyphnames():
     check = CheckTester(universal_profile,
                         "com.google.fonts/check/whitespace_glyphnames")
 
-    def deleteGlyphEncodings(font, cp):
-        """ This routine is used on to introduce errors
-            in a given font by removing specific entries
-            in the cmap tables.
-        """
-        for subtable in font['cmap'].tables:
-            if subtable.isUnicode():
-                subtable.cmap = {
-                    codepoint: name for codepoint, name in subtable.cmap.items()
-                    if codepoint != cp
-                }
-
     def editCmap(font, cp, name):
         """ Corrupt the cmap by changing the glyph name
             for a given code point.
@@ -391,7 +471,6 @@ def test_check_whitespace_glyphnames():
     assert_PASS(check(ttFont),
                 'with a good font...')
 
-
     value = ttFont["post"].formatType
     ttFont["post"].formatType = 3.0
     assert_SKIP(check(ttFont),
@@ -400,21 +479,16 @@ def test_check_whitespace_glyphnames():
     # restore good value:
     ttFont["post"].formatType = value
 
-
-    deleteGlyphEncodings(ttFont, 0x0020)
-    assert_results_contain(check(ttFont),
-                           FAIL, 'missing-0020',
-                           'with missing glyph name for char 0x0020 ...')
-
+    _remove_cmap_entry(ttFont, 0x0020)
+    msg = assert_results_contain(check(ttFont), SKIP, "unfulfilled-conditions")
+    assert msg == "Unfulfilled Conditions: not missing_whitespace_chars"
 
     # restore the original font object in preparation for the next test-case:
     ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
 
-    deleteGlyphEncodings(ttFont, 0x00A0)
-    assert_results_contain(check(ttFont),
-                           FAIL, 'missing-00a0',
-                           'with missing glyph name for char 0x00A0 ...')
-
+    _remove_cmap_entry(ttFont, 0x00A0)
+    msg = assert_results_contain(check(ttFont), SKIP, "unfulfilled-conditions")
+    assert msg == "Unfulfilled Conditions: not missing_whitespace_chars"
 
     # restore the original font object in preparation for the next test-case:
     ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
@@ -426,28 +500,25 @@ def test_check_whitespace_glyphnames():
                            FAIL, 'non-compliant-00a0',
                            'with not AGL-compliant glyph name "nbsp" for char 0x00A0...')
 
-
     editCmap(ttFont, 0x00A0, "nbspace")
     assert_results_contain(check(ttFont),
                            WARN, 'not-recommended-00a0',
                            'for naming 0x00A0 "nbspace"...')
 
-
     editCmap(ttFont, 0x0020, "foo")
     assert_results_contain(check(ttFont),
                            FAIL, 'non-compliant-0020',
                            'with not AGL-compliant glyph name "foo" for char 0x0020...')
 
-
     editCmap(ttFont, 0x0020, "uni0020")
     assert_results_contain(check(ttFont),
                            WARN, 'not-recommended-0020',
                            'for naming 0x0020 "uni0020"...')
 
-
     editCmap(ttFont, 0x0020, "space")
     editCmap(ttFont, 0x00A0, "uni00A0")
-    assert_PASS(check(ttFont))
+    assert assert_PASS(check(ttFont)) == (
+        "Font has **AGL recommended** names for whitespace glyphs.")
 
 
 def test_check_whitespace_ink():
@@ -486,19 +557,75 @@ def test_check_required_tables():
     check = CheckTester(universal_profile,
                         "com.google.fonts/check/required_tables")
 
-    required_tables = ["cmap", "head", "hhea", "hmtx",
+    REQUIRED_TABLES = ["cmap", "head", "hhea", "hmtx",
                        "maxp", "name", "OS/2", "post"]
-    optional_tables = ["cvt ", "fpgm", "loca", "prep",
+
+    OPTIONAL_TABLES = ["cvt ", "fpgm", "loca", "prep",
                        "VORG", "EBDT", "EBLC", "EBSC",
                        "BASE", "GPOS", "GSUB", "JSTF",
-                       "gasp", "hdmx", "kern", "LTSH",
-                       "PCLT", "VDMX", "vhea", "vmtx"]
-    # Our reference Mada Regular font is good here
-    ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
+                       "gasp", "hdmx", "LTSH", "PCLT",
+                       "VDMX", "vhea", "vmtx", "kern"]
 
-    # So it must PASS the check:
-    assert_PASS(check(ttFont),
-                'with a good font...')
+    # Valid reference fonts, one for each format.
+    # TrueType: Mada Regular
+    # OpenType-CFF: SourceSansPro-Black
+    # OpenType-CFF2: SourceSansVariable-Italic
+    ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
+    cff_font = TTFont(TEST_FILE("source-sans-pro/OTF/SourceSansPro-Black.otf"))
+    cff2_font = TTFont(TEST_FILE("source-sans-pro/VAR/SourceSansVariable-Italic.otf"))
+
+    # The TrueType font contains all required tables, so it must PASS the check.
+    msg = assert_PASS(check(ttFont), 'with a good font...')
+    assert msg == "Font contains all required tables."
+
+    # Here we confirm that the check also yields INFO with
+    # a list of table tags specific to the font.
+    msg = assert_results_contain(check(ttFont), INFO, "optional-tables")
+    for tag in {"loca", "GPOS", "GSUB"}:
+        assert tag in msg
+
+    # The OpenType-CFF font contains all required tables, so it must PASS the check.
+    msg = assert_PASS(check(cff_font), 'with a good font...')
+    assert msg == "Font contains all required tables."
+
+    # Here we confirm that the check also yields INFO with
+    # a list of table tags specific to the OpenType-CFF font.
+    msg = assert_results_contain(check(cff_font), INFO, "optional-tables")
+    for tag in {"BASE", "GPOS", "GSUB"}:
+        assert tag in msg
+
+    # The font must also contain the table that holds the outlines, "CFF " in this case.
+    del cff_font.reader.tables["CFF "]
+    msg = assert_results_contain(check(cff_font), FAIL, "required-tables")
+    assert "CFF " in msg
+
+    # The OpenType-CFF2 font contains all required tables, so it must PASS the check.
+    msg = assert_PASS(check(cff2_font), 'with a good font...')
+    assert msg == "Font contains all required tables."
+
+    # Here we confirm that the check also yields INFO with
+    # a list of table tags specific to the OpenType-CFF2 font.
+    msg = assert_results_contain(check(cff2_font), INFO, "optional-tables")
+    for tag in {"BASE", "GPOS", "GSUB"}:
+        assert tag in msg
+
+    # The font must also contain the table that holds the outlines, "CFF2" in this case.
+    del cff2_font.reader.tables["CFF2"]
+    msg = assert_results_contain(check(cff2_font), FAIL, "required-tables")
+    assert "CFF2" in msg
+
+    # The OT-CFF2 font is variable, so a "STAT" table is also required.
+    # Here we confirm that the check fails when the "STAT" table is removed.
+    del cff2_font.reader.tables["STAT"]
+    msg = assert_results_contain(check(cff2_font), FAIL, "required-tables")
+    assert "STAT" in msg
+
+    # Here we also remove the "fvar" table from the OT-CFF2 font.
+    # Without an "fvar" table the font is validated as if it were a stactic font,
+    # leading the check to FAIL with a message about the lack of a "CFF " table.
+    del cff2_font.reader.tables["fvar"]
+    msg = assert_results_contain(check(cff2_font), FAIL, "required-tables")
+    assert "CFF " in msg
 
     # Now we test the special cases for variable fonts:
     #
@@ -509,39 +636,47 @@ def test_check_required_tables():
     # TODO: Maybe we could someday emit a more explicit
     #       message to the users regarding that...
     ttFont.reader.tables["fvar"] = "foo"
-    assert_results_contain(check(ttFont),
-                           FAIL, "required-tables",
-                           'with fvar but no STAT...')
+    msg = assert_results_contain(check(ttFont),
+                                 FAIL, "required-tables",
+                                 'with fvar but no STAT...')
+    assert "STAT" in msg
 
     del ttFont.reader.tables["fvar"]
     ttFont.reader.tables["STAT"] = "foo"
-    assert_PASS(check(ttFont),
-                'with STAT on a non-variable font...')
+    msg = assert_PASS(check(ttFont),
+                      'with STAT on a non-variable font...')
+    assert msg == "Font contains all required tables."
 
     # and finally remove what we've just added:
     del ttFont.reader.tables["STAT"]
+
     # Now we remove required tables one-by-one to validate the FAIL code-path:
-    for required in required_tables:
+    # The font must also contain the table that holds the outlines, "glyf" in this case.
+    for required in REQUIRED_TABLES + ["glyf"]:
         ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
         if required in ttFont.reader.tables:
             del ttFont.reader.tables[required]
-        assert_results_contain(check(ttFont),
-                               FAIL, "required-tables",
-                               f'with missing mandatory table {required} ...')
+        msg = assert_results_contain(check(ttFont),
+                                     FAIL, "required-tables",
+                                     f'with missing mandatory table {required} ...')
+        assert required in msg
+
     # Then, in preparation for the next step, we make sure
     # there's no optional table (by removing them all):
-    for optional in optional_tables:
+    for optional in OPTIONAL_TABLES:
         if optional in ttFont.reader.tables:
             del ttFont.reader.tables[optional]
 
     # Then re-insert them one by one to validate the INFO code-path:
-    for optional in optional_tables:
+    for optional in OPTIONAL_TABLES:
         ttFont.reader.tables[optional] = "foo"
         # and ensure that the second to last logged message is an
         # INFO status informing the user about it:
-        assert_results_contain(check(ttFont),
-                               INFO, "optional-tables",
-                               f'with optional table {required} ...')
+        msg = assert_results_contain(check(ttFont),
+                                     INFO, "optional-tables",
+                                     f'with optional table {required} ...')
+        assert optional in msg
+
         # remove the one we've just inserted before trying the next one:
         del ttFont.reader.tables[optional]
 
@@ -585,21 +720,21 @@ def test_glyph_has_ink():
 
     cff_test_font = TTFont(TEST_FILE("source-sans-pro/OTF/SourceSansPro-Regular.otf"))
     print('Test if CFF glyph with ink has ink')
-    assert(glyph_has_ink(cff_test_font, '.notdef') is True)
+    assert glyph_has_ink(cff_test_font, '.notdef') is True
     print('Test if CFF glyph without ink has ink')
-    assert(glyph_has_ink(cff_test_font, 'space') is False)
+    assert glyph_has_ink(cff_test_font, 'space') is False
 
     ttf_test_font = TTFont(TEST_FILE("source-sans-pro/TTF/SourceSansPro-Regular.ttf"))
     print('Test if TTF glyph with ink has ink')
-    assert(glyph_has_ink(ttf_test_font, '.notdef') is True)
+    assert glyph_has_ink(ttf_test_font, '.notdef') is True
     print('Test if TTF glyph without ink has ink')
-    assert(glyph_has_ink(ttf_test_font, 'space') is False)
+    assert glyph_has_ink(ttf_test_font, 'space') is False
 
     cff2_test_font = TTFont(TEST_FILE("source-sans-pro/VAR/SourceSansVariable-Roman.otf"))
     print('Test if CFF2 glyph with ink has ink')
-    assert(glyph_has_ink(cff2_test_font, '.notdef') is True)
+    assert glyph_has_ink(cff2_test_font, '.notdef') is True
     print('Test if CFF2 glyph without ink has ink')
-    assert(glyph_has_ink(cff2_test_font, 'space') is False)
+    assert glyph_has_ink(cff2_test_font, 'space') is False
 
 
 mada_fonts = [
@@ -648,13 +783,19 @@ def test_check_family_win_ascent_and_descent(mada_ttFonts):
                            'with a bad OS/2.usWinDescent...')
 
 
-def test_check_os2_metrics_match_hhea(mada_ttFonts):
+def test_check_os2_metrics_match_hhea():
     """ Checking OS/2 Metrics match hhea Metrics. """
     check = CheckTester(universal_profile,
                         "com.google.fonts/check/os2_metrics_match_hhea")
 
-    # Our reference Mada Regular is know to be good here.
+    # Our reference Mada Regular is know to be faulty here.
     ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
+    assert_results_contain(check(ttFont),
+                           FAIL, 'lineGap',
+                           'OS/2 sTypoLineGap (100) and hhea lineGap (96) must be equal.')
+
+    # Our reference Mada Black is know to be good here.
+    ttFont = TTFont(TEST_FILE("mada/Mada-Black.ttf"))
 
     assert_PASS(check(ttFont),
                 'with a good font...')
@@ -763,8 +904,17 @@ def test_check_unreachable_glyphs():
     font = TEST_FILE("noto_sans_tamil_supplement/NotoSansTamilSupplement-Regular.ttf")
     assert_PASS(check(font))
 
+    # Also ensure it works correctly with a color font in COLR v0 format:
+    font = TEST_FILE("color_fonts/AmiriQuranColored.ttf")
+    assert_PASS(check(font))
+
+    # And also with a color font in COLR v1 format:
+    font = TEST_FILE("color_fonts/noto-glyf_colr_1.ttf")
+    assert_PASS(check(font))
+
     font = TEST_FILE("merriweather/Merriweather-Regular.ttf")
-    message = assert_results_contain(check(font), WARN, "unreachable-glyphs")
+    message = assert_results_contain(check(font),
+                                     WARN, "unreachable-glyphs")
     for glyph in [
         "Gtilde",
         "eight.dnom",
@@ -828,11 +978,11 @@ def test_check_cjk_chws_feature():
     cjk_font = TEST_FILE("cjk/SourceHanSans-Regular.otf")
     ttFont = TTFont(cjk_font)
     assert_results_contain(check(ttFont),
-                           FAIL, "missing-chws-feature",
+                           WARN, "missing-chws-feature",
                            'for Source Han Sans')
 
     assert_results_contain(check(ttFont),
-                           FAIL, "missing-vchw-feature",
+                           WARN, "missing-vchw-feature",
                            'for Source Han Sans')
 
     # Insert them.
@@ -902,10 +1052,16 @@ def test_check_transformed_components():
                 "with a good font...")
 
     # DM Sans v1.100 had some transformed components
+    # and it's hinted
     font = TEST_FILE("dm-sans-v1.100/DMSans-Regular.ttf")
     assert_results_contain(check(font),
                            FAIL, 'transformed-components')
 
+    # Amiri is unhinted, but it contains four transformed components
+    # that result in reversed outline direction
+    font = TEST_FILE("amiri/AmiriQuranColored.ttf")
+    assert_results_contain(check(font),
+                           FAIL, 'transformed-components')
 
 def test_check_dotted_circle():
     """Ensure dotted circle glyph is present and can attach marks."""
@@ -925,11 +1081,11 @@ def test_check_dotted_circle():
                            FAIL, "unattached-dotted-circle-marks")
 
 
-def test_check_gsub5_gpos7():
-    """Check if font contains any GSUB 5 or GPOS 7 lookups
+def test_check_gpos7():
+    """Check if font contains any GPOS 7 lookups
     which are not widely supported."""
     check = CheckTester(universal_profile,
-                        "com.google.fonts/check/gsub5_gpos7")
+                        "com.google.fonts/check/gpos7")
 
     font = TEST_FILE("mada/Mada-Regular.ttf")
     assert_PASS(check(font),
@@ -937,7 +1093,72 @@ def test_check_gsub5_gpos7():
 
     font = TEST_FILE("notosanskhudawadi/NotoSansKhudawadi-Regular.ttf")
     assert_results_contain(check(font),
-                           FAIL, "has-gsub5")
+                           WARN, "has-gpos7")
 
-    assert_results_contain(check(font),
-                           FAIL, "has-gpos7")
+
+def test_check_freetype_rasterizer():
+    """Ensure that the font can be rasterized by FreeType."""
+    check = CheckTester(universal_profile, "com.adobe.fonts/check/freetype_rasterizer")
+
+    font = TEST_FILE("cabin/Cabin-Regular.ttf")
+    msg = assert_PASS(check(font), "with a good font...")
+    assert msg == "Font can be rasterized by FreeType."
+
+    font = TEST_FILE("ancho/AnchoGX.ttf")
+    msg = assert_results_contain(check(font), FAIL, "freetype-crash")
+    assert "FT_Exception:  (too many function definitions)" in msg
+
+    font = TEST_FILE("rubik/Rubik-Italic.ttf")
+    msg = assert_results_contain(check(font), FAIL, "freetype-crash")
+    assert "FT_Exception:  (stack overflow)" in msg
+
+
+def test_check_sfnt_version():
+    """Ensure that the font has the proper sfntVersion value."""
+    check = CheckTester(universal_profile, "com.adobe.fonts/check/sfnt_version")
+
+    # Valid TrueType font; the check must PASS.
+    ttFont = TTFont(TEST_FILE("cabinvf/Cabin[wdth,wght].ttf"))
+    msg = assert_PASS(check(ttFont))
+    assert msg == "Font has the correct sfntVersion value."
+
+    # Change the sfntVersion to an improper value for TrueType fonts.
+    # The check should FAIL.
+    ttFont.sfntVersion = "OTTO"
+    msg = assert_results_contain(check(ttFont), FAIL, "wrong-sfnt-version-ttf")
+    assert msg == "Font with TrueType outlines has incorrect sfntVersion value: 'OTTO'"
+
+    # Valid CFF font; the check must PASS.
+    ttFont = TTFont(TEST_FILE("source-sans-pro/OTF/SourceSansPro-Bold.otf"))
+    msg = assert_PASS(check(ttFont))
+    assert msg == "Font has the correct sfntVersion value."
+
+    # Change the sfntVersion to an improper value for CFF fonts. The check should FAIL.
+    ttFont.sfntVersion = "\x00\x01\x00\x00"
+    msg = assert_results_contain(check(ttFont), FAIL, "wrong-sfnt-version-cff")
+    assert msg == (
+        "Font with CFF data has incorrect sfntVersion value: '\x00\x01\x00\x00'")
+
+    # Valid CFF2 font; the check must PASS.
+    ttFont = TTFont(TEST_FILE("source-sans-pro/VAR/SourceSansVariable-Roman.otf"))
+    msg = assert_PASS(check(ttFont))
+    assert msg == "Font has the correct sfntVersion value."
+
+    # Change the sfntVersion to an improper value for CFF fonts. The check should FAIL.
+    ttFont.sfntVersion = "\x00\x01\x00\x00"
+    msg = assert_results_contain(check(ttFont), FAIL, "wrong-sfnt-version-cff")
+    assert msg == (
+        "Font with CFF data has incorrect sfntVersion value: '\x00\x01\x00\x00'")
+
+
+def test_check_whitespace_widths():
+    """ Whitespace glyphs have coherent widths? """
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/whitespace_widths")
+
+    ttFont = TTFont(TEST_FILE("nunito/Nunito-Regular.ttf"))
+    assert_PASS(check(ttFont))
+
+    ttFont["hmtx"].metrics["space"] = (0, 1)
+    assert_results_contain(check(ttFont),
+                           FAIL, 'different-widths')
